==> dagster_ssh-0.5.6.tar.gz: dagster_ssh-0.5.6/setup.py <==
import argparse
import sys

from setuptools import find_packages, setup


def get_version(name):
    version = {}
    with open('dagster_ssh/version.py') as fp:
        exec(fp.read(), version)  # pylint: disable=W0122

    if name == 'dagster-ssh':
        return version['__version__']
    elif name == 'dagster-ssh-nightly':
        return version['__nightly__']
    else:
        raise Exception('Shouldn\'t be here: bad package name {name}'.format(name=name))


parser = argparse.ArgumentParser()
parser.add_argument('--nightly', action='store_true')


def _do_setup(name='dagster-ssh'):
    setup(
        name='dagster_ssh',
        version=get_version(name),
        author='Elementl',
        license='Apache-2.0',
        description='Package for ssh Dagster framework components.',
        url='https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-ssh',
        classifiers=[
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
        ],
        packages=find_packages(exclude=['test']),
        install_requires=['dagster', 'sshtunnel==0.1.5', 'paramiko==2.4.*'],
        tests_require=['mock==2.0.*'],
        zip_safe=False,
    )


if __name__ == '__main__':
    parsed, unparsed = parser.parse_known_args()
    sys.argv = [sys.argv[0]] + unparsed
    if parsed.nightly:
        _do_setup('dagster-ssh-nightly')
    else:
        _do_setup('dagster-ssh')

==> dagster_ssh-0.5.8.tar.gz: dagster_ssh-0.5.8/setup.py <==
import argparse
import sys

from setuptools import find_packages, setup


def get_version(name):
    version = {}
    with open('dagster_ssh/version.py') as fp:
        exec(fp.read(), version)  # pylint: disable=W0122

    if name == 'dagster-ssh':
        return version['__version__']
    elif name == 'dagster-ssh-nightly':
        return version['__nightly__']
    else:
        raise Exception('Shouldn\'t be here: bad package name {name}'.format(name=name))


parser = argparse.ArgumentParser()
parser.add_argument('--nightly', action='store_true')


def _do_setup(name='dagster-ssh'):
    setup(
        name='dagster_ssh',
        version=get_version(name),
        author='Elementl',
        license='Apache-2.0',
        description='Package for ssh Dagster framework components.',
        url='https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-ssh',
        classifiers=[
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
        ],
        packages=find_packages(exclude=['test']),
        install_requires=['dagster', 'sshtunnel==0.1.5', 'paramiko==2.4.*'],
        tests_require=['mock==2.0.*', 'pytest-sftpserver==1.2.*'],
        zip_safe=False,
    )


if __name__ == '__main__':
    parsed, unparsed = parser.parse_known_args()
    sys.argv = [sys.argv[0]] + unparsed
    if parsed.nightly:
        _do_setup('dagster-ssh-nightly')
    else:
        _do_setup('dagster-ssh')
